==> meteor-bootstrap_key-value-tag-input-2.5.2.tgz: package/src/keyValueTypes/KeyValueType.js <==
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
import { KeyValueEntry } from "./KeyValueEntry";
var KeyValueType = /** @class */ (function () {
    function KeyValueType(id, label, aliases) {
        if (aliases === void 0) { aliases = []; }
        this._id = id;
        this._label = label;
        this._aliases = __spreadArrays([id, label], aliases).map(function (a) { return a.toLowerCase(); });
    }
    Object.defineProperty(KeyValueType.prototype, "id", {
        get: function () {
            return this._id;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(KeyValueType.prototype, "label", {
        get: function () {
            return this._label;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(KeyValueType.prototype, "aliases", {
        get: function () {
            return this._aliases;
        },
        enumerable: true,
        configurable: true
    });
    KeyValueType.prototype.findAlias = function (substring) {
        var substringLower = substring.toLowerCase();
        return this.aliases.find(function (a) { return a.includes(substringLower); });
    };
    KeyValueType.prototype.createPartialEntry = function () {
        return new KeyValueEntry(this);
    };
    KeyValueType.prototype.tryCreatePartialEntry = function (key) {
        if (!this.aliases.includes(key.toLowerCase())) {
            return undefined;
        }
        return new KeyValueEntry(this);
    };
    KeyValueType.prototype.tryCreateFullEntry = function (val) {
        var entry = new KeyValueEntry(this);
        if (entry.set(val)) {
            return entry;
        }
        else {
            return undefined;
        }
    };
    KeyValueType.prototype.isEqual = function (entryA, entryB) {
        return entryA.type === entryB.type && entryA.value === entryB.value;
    };
    return KeyValueType;
}());
export { KeyValueType };

==> meteor-bootstrap_key-value-tag-input-3.3.1.tgz: package/src/keyValueTypes/KeyValueType.js <==
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
import { KeyValueEntry } from "./KeyValueEntry";
var KeyValueType = /** @class */ (function () {
    function KeyValueType(id, label, aliases) {
        if (aliases === void 0) { aliases = []; }
        this._id = id;
        this._label = label;
        this._aliases = __spreadArrays([id, label], aliases).map(function (a) { return a.toLowerCase(); });
    }
    Object.defineProperty(KeyValueType.prototype, "id", {
        get: function () {
            return this._id;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(KeyValueType.prototype, "label", {
        get: function () {
            return this._label;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(KeyValueType.prototype, "aliases", {
        get: function () {
            return this._aliases;
        },
        enumerable: true,
        configurable: true
    });
    KeyValueType.prototype.findAlias = function (substring) {
        var substringLower = substring.toLowerCase();
        return this.aliases.find(function (a) { return a.includes(substringLower); });
    };
    KeyValueType.prototype.createPartialEntry = function () {
        return new KeyValueEntry(this);
    };
    KeyValueType.prototype.tryCreatePartialEntry = function (key) {
        if (!this.aliases.includes(key.toLowerCase())) {
            return undefined;
        }
        return new KeyValueEntry(this);
    };
    KeyValueType.prototype.tryCreateFullEntry = function (val) {
        var entry = new KeyValueEntry(this);
        if (entry.set(val)) {
            return entry;
        }
        else {
            return undefined;
        }
    };
    KeyValueType.prototype.isEqual = function (entryA, entryB) {
        return entryA.type === entryB.type && this.isValueEqual(entryA.value, entryB.value);
    };
    KeyValueType.prototype.isValueEqual = function (valueA, valueB) {
        return valueA === valueB;
    };
    return KeyValueType;
}());
export { KeyValueType };
